#
# spec file for package autotrace
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_ver 3
%define sh_lib lib%{name}%{so_ver}
Name:           autotrace
Version:        0.31.10
Release:        1.1
Summary:        Program for Converting Bitmaps to Vector Graphics
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
URL:            https://github.com/autotrace/autotrace
Source:         %{url}/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM autotrace-pkgconfig-private-libs.patch gh#autotrace/autotrace#124 badshah400@gmail.com -- [pkgconfig] Move some libraries to Libs.private
Patch0:         https://github.com/autotrace/autotrace/commit/eeeb813a416ff309804f6833729fab20d036e667.patch#/autotrace-pkgconfig-private-libs.patch
# PATCH-FIX-UPSTREAM autotrace-ac_subst-magick-vars.patch gh#autotrace/autotrace#160 badshah400@gmail.com -- Fix unexpanded MAGICK_* variables in pkgconfig file
Patch1:         autotrace-ac_subst-magick-vars.patch
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkgconfig
# Tests need pkill
BuildRequires:  procps
BuildRequires:  pkgconfig(ImageMagick)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(pstoedit)
Provides:       bitmap_tracing

%description
AutoTrace is a program for converting bitmaps to vector graphics. The
aim of the AutoTrace project is the development of a freely-available
application similar to CorelTrace or Adobe Streamline. In some aspects,
it is already better. Originally created as a plug-in for the GIMP,
AutoTrace is now a stand-alone program and can be compiled on any UNIX
platform using GCC.

%package -n %{sh_lib}
Summary:        Library for converting bitmaps to vector graphics
Group:          System/Libraries

%description -n %{sh_lib}
AutoTrace is a program for converting bitmaps to vector graphics. The
aim of the AutoTrace project is the development of a freely-available
application similar to CorelTrace or Adobe Streamline. In some aspects,
it is already better. Originally created as a plug-in for the GIMP,
AutoTrace is now a stand-alone program and can be compiled on any UNIX
platform using GCC.

%package devel
Summary:        Library for converting bitmaps to vector graphics
Group:          Development/Libraries/C and C++
Requires:       %{sh_lib} = %{version}
Requires:       pkgconfig
Requires:       pkgconfig(ImageMagick)
Requires:       pkgconfig(glib-2.0)
Requires:       pkgconfig(gmodule-2.0)
Requires:       pkgconfig(gobject-2.0)
Requires:       pkgconfig(pstoedit)

%description devel
AutoTrace is a program for converting bitmaps to vector graphics. The
aim of the AutoTrace project is the development of a freely-available
application similar to CorelTrace or Adobe Streamline. In some aspects,
it is already better. Originally created as a plug-in for the GIMP,
AutoTrace is now a stand-alone program and can be compiled on any UNIX
platform using GCC.

%lang_package

%prep
%autosetup -p1

%build
./autogen.sh
%configure \
  --enable-magick-readers \
  --disable-static \
  %{nil}
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name} %{?no_lang_C}

%check
%make_build check

%ldconfig_scriptlets -n %{sh_lib}

%files
%license COPYING
%doc AUTHORS FAQ NEWS README.md THANKS TODO
%{_bindir}/autotrace
%{_mandir}/man1/autotrace.1%{?ext_man}

%files -n %{sh_lib}
%license COPYING.LIB
%{_libdir}/*.so.*

%files devel
%license COPYING.LIB COPYING
%{_includedir}/autotrace
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files lang -f %{name}.lang

%changelog
* Sun Jun  1 2025 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.31.10:
  * ImageMagick 7 support (gh#autotrace/autotrace#105,
    gh#autotrace/autotrace#106).
  * HKUST CVEs addressed (gh#autotrace/autotrace#110).
- Drop upstreamed or otherwise unnecessary patches:
  * autotrace-0.31.1-quotefix.diff (autotrace.m4 dropped, commit
    64823fa).
  * 0001-fix_input_png.patch (commit 70b315a).
  * CVE-2019-19004.patch (commit 64c5833).
  * CVE-2019-19005.patch (commit 268aee4).
  * CVE-2022-32323.patch (comimt aaf410d).
- Add autotrace-pkgconfig-private-libs.patch: [pkgconfig] Move
  some libraries to Libs.private (gh#autotrace/autotrace#124).
- Add autotrace-ac_subst-magick-vars.patch: Fix unexpanded
  MAGICK_* automake variables in pkgconfig file
  (gh#autotrace/autotrace#160).
- Drop additional pstoedit.m4 file source as not needed any more.
- Use full URL for Source0.
- Split off separate lang package.
- Run tests as part of %%check section; add BuildRequires: procps
  for pkill command used in some tests.
- Specfile cleanups.
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Nov  8 2022 Jason Sikes <jsikes@suse.com>
- Added CVE-2022-32323.patch
  * [bsc#1201529, CVE-2022-32323]
  * Fixes Heap overflow in ReadImage()
* Fri May 13 2022 Stanislav Brabec <sbrabec@suse.com>
- biWidth*biBitCnt integer overflow fix (bsc#1182158,
  CVE-2019-19004, CVE-2019-19004.patch).
- Bitmap double free fix (bsc1182159, CVE-2019-19005,
  CVE-2017-9182, CVE-2017-9190, CVE-2019-19005.patch).
* Tue Aug 12 2014 sfalken@opensuse.org
- Add 0001-fix_input_png.patch:  Corrects build failure against libpng15
- Updated .spec file to use %%make_install macro
* Thu Feb 28 2013 coolo@suse.com
- update license to new format
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Mon Mar  7 2011 sbrabec@suse.cz
- Split according to shared library packaging rules.
- Enabled ImageMagick support.
* Mon Dec 20 2010 meissner@suse.de
- libexif does not seem to be directly required
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Tue Apr 21 2009 crrodriguez@suse.de
- remove static libraries and "la" files
- cleanup spec file a bit
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan  6 2005 sbrabec@suse.cz
- Provide bitmap_tracing virtual.
* Tue Dec  7 2004 pth@suse.de
- Fix AC_DEFUN quoting
* Mon Jun 28 2004 ro@suse.de
- added libjpeg,libtiff to neededforbuild
* Sun Apr 25 2004 ro@suse.de
- added no-strict-aliasing
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Mon Jul 28 2003 meissner@suse.de
- added libexif to nfb
* Mon May 26 2003 ro@suse.de
- add manpage to filelist
* Sat May 10 2003 schwab@suse.de
- Force libtool update.
* Thu Dec 26 2002 ro@suse.de
- added liblcms-devel to neededforbuild
* Thu Nov 21 2002 sbrabec@suse.cz
- Added new package.
- Libtool updates, otherwise cannot create shared   library (autoreconf
  needs extra macro in pstoedit.m4).
